@@ -23,7 +23,7 @@ from .lib.user_interaction import *
 
 parser = ArgumentParser()
 
-__version__ = "2.3.0"
+__version__ = "2.3.1"
 storage['__version__'] = __version__
 
 
@@ -86,8 +86,10 @@ from .lib.plugins import plugins, load_plugin # This initiates the plugin loadin
 if arguments.get('plugin', None):
 	load_plugin(arguments['plugin'])
 
-# TODO: Learn the dark arts of argparse... (I summon thee dark spawn of cPython)
-
+# @archinstall.plugin decorator hook to programmatically add
+# plugins in runtime. Useful in profiles and other things.
+def plugin(f, *args, **kwargs):
+	plugins[f.__name__] = f
 
 def run_as_a_module():
 	"""
